@@ -22,9 +22,15 @@
 #' data(agaricus.train)
 #' data(agaricus.test)
 #'
-#' xgb <- xgboost(data = agaricus.train$data, label = agaricus.train$label,
-#'                max_depth = 2, eta = 1, nthread = 2, nrounds = 2,
-#'                objective = "binary:logistic")
+#' if (utils::packageVersion("xgboost") >= "2.0.0.0") {
+#'   xgb <- xgboost(x = agaricus.train$data, y = agaricus.train$label,
+#'                  max_depth = 2, learning_rate = 1, nthread = 2, nrounds = 2,
+#'                  objective = "reg:squarederror")
+#' } else {
+#'   xgb <- xgboost(data = agaricus.train$data, label = agaricus.train$label,
+#'                  max_depth = 2, eta = 1, nthread = 2, nrounds = 2,
+#'                  objective = "binary:logistic")
+#' }
 #'
 #' xgb_bundle <- bundle(xgb)
 #'
@@ -44,15 +50,27 @@ bundle.xgb.Booster <- function(x, ...) {
   bundle_constr(
     object = object,
     situate = situate_constr(function(object) {
-      res <- xgboost::xgb.load.raw(object, as_booster = TRUE)
+      if (utils::packageVersion("xgboost") > "2.0.0.0") {
+        res <- xgboost::xgb.load.raw(object)
 
-      res$params <- list(
-        objective = !!x$params$objective,
-        num_class = !!x$params$num_class
-      )
+        attr(res, "params") <- list(
+          objective = !!attr(x, "params")$objective,
+          num_class = !!attr(x, "params")$num_class
+        )
 
-      res$nfeatures <- !!x$nfeatures
-      res$feature_names <- !!x$feature_names
+        attr(res, "nfeatures") <- !!attr(x, "nfeatures")
+        attr(res, "feature_names") <- !!attr(x, "feature_names")
+      } else {
+        res <- xgboost::xgb.load.raw(object, as_booster = TRUE)
+
+        res$params <- list(
+          objective = !!x$params$objective,
+          num_class = !!x$params$num_class
+        )
+
+        res$nfeatures <- !!x$nfeatures
+        res$feature_names <- !!x$feature_names
+      }
 
       res
     }),
